@@ -251,11 +251,7 @@ LIS_INT lis_bicg(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
@@ -407,11 +403,7 @@ LIS_INT lis_bicg_quad(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol > nrm2 )
@@ -572,11 +564,7 @@ LIS_INT lis_bicg_switch(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( nrm2 <= tol2 )
@@ -678,11 +666,7 @@ LIS_INT lis_bicg_switch(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter2] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter2, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter2, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol > nrm2 )
@@ -892,11 +876,7 @@ LIS_INT lis_bicr(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
@@ -1046,11 +1026,7 @@ LIS_INT lis_bicr_quad(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
