@@ -270,11 +270,7 @@ LIS_INT lis_bicgsafe(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
@@ -532,11 +528,7 @@ LIS_INT lis_bicgsafe_quad(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol > nrm2 )
@@ -760,11 +752,7 @@ LIS_INT lis_bicgsafe_switch(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol2 >= nrm2 )
@@ -936,11 +924,7 @@ LIS_INT lis_bicgsafe_switch(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter2] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter2, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter2, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol > nrm2 )
@@ -1194,11 +1178,7 @@ LIS_INT lis_bicrsafe(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
@@ -1414,11 +1394,7 @@ LIS_INT lis_bicrsafe_quad(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
