@@ -242,11 +242,7 @@ LIS_INT lis_bicgstab(LIS_SOLVER solver)
 			if( output )
 			{
 				if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+				if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 			}
 
 			lis_vector_axpy(alpha,phat,x);
@@ -288,11 +284,7 @@ LIS_INT lis_bicgstab(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
@@ -447,11 +439,7 @@ LIS_INT lis_bicgstab_quad(LIS_SOLVER solver)
 			if( output )
 			{
 				if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+				if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 			}
 
 			lis_quad_minus((LIS_QUAD *)alpha.hi);
@@ -494,11 +482,7 @@ LIS_INT lis_bicgstab_quad(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol > nrm2 )
@@ -658,11 +642,7 @@ LIS_INT lis_bicgstab_switch(LIS_SOLVER solver)
 				if( output )
 				{
 					if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+					if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 				}
 
 				lis_vector_axpy(alpha.hi[0],phat,x);
@@ -699,11 +679,7 @@ LIS_INT lis_bicgstab_switch(LIS_SOLVER solver)
 			if( output )
 			{
 				if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+				if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 			}
 
 			if( nrm2 <= tol2 )
@@ -808,11 +784,7 @@ LIS_INT lis_bicgstab_switch(LIS_SOLVER solver)
 				if( output )
 				{
 					if( output & LIS_PRINT_MEM ) solver->residual[iter2] = nrm2;
-#ifdef _LONGLONG
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter2, nrm2);
-#else
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter2, nrm2);
-#endif
+					if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 				}
 
 				lis_quad_minus((LIS_QUAD *)alpha.hi);
@@ -856,11 +828,7 @@ LIS_INT lis_bicgstab_switch(LIS_SOLVER solver)
 			if( output )
 			{
 				if( output & LIS_PRINT_MEM ) solver->residual[iter2] = nrm2;
-#ifdef _LONGLONG
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter2, nrm2);
-#else
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter2, nrm2);
-#endif
+				if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 			}
 
 			if( tol > nrm2 )
@@ -1055,11 +1023,7 @@ LIS_INT lis_bicrstab(LIS_SOLVER solver)
 			if( output )
 			{
 				if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+				if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 			}
 
 			lis_vector_axpy(alpha,p,x);
@@ -1093,11 +1057,7 @@ LIS_INT lis_bicrstab(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
@@ -1224,11 +1184,7 @@ LIS_INT lis_bicrstab_quad(LIS_SOLVER solver)
 			if( output )
 			{
 				if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-				if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+				if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 			}
 
 			lis_quad_minus((LIS_QUAD *)alpha.hi);
@@ -1265,11 +1221,7 @@ LIS_INT lis_bicrstab_quad(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
