@@ -299,11 +299,7 @@ LIS_INT lis_bicgstabl(LIS_SOLVER solver)
 				if( output )
 				{
 					if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+					if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 				}
 			}
 
@@ -312,11 +308,7 @@ LIS_INT lis_bicgstabl(LIS_SOLVER solver)
 				if( output )
 				{
 					if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+					if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 				}	
 				times = lis_wtime();
 				lis_psolve(solver, x, t);
@@ -399,11 +391,7 @@ LIS_INT lis_bicgstabl(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol >= nrm2 )
@@ -637,11 +625,7 @@ LIS_INT lis_bicgstabl_quad(LIS_SOLVER solver)
 				if( output )
 				{
 					if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+					if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 				}
 			}
 
@@ -650,11 +634,7 @@ LIS_INT lis_bicgstabl_quad(LIS_SOLVER solver)
 				if( output )
 				{
 					if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-					if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+					if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 				}	
 				lis_vector_axpyex_mmm(one,xp,x);
 				solver->retcode    = LIS_SUCCESS;
@@ -762,11 +742,7 @@ LIS_INT lis_bicgstabl_quad(LIS_SOLVER solver)
 		if( output )
 		{
 			if( output & LIS_PRINT_MEM ) solver->residual[iter] = nrm2;
-#ifdef _LONGLONG
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5lld  residual = %e\n", iter, nrm2);
-#else
-			if( output & LIS_PRINT_OUT && A->my_rank==0 ) printf("iter: %5d  residual = %e\n", iter, nrm2);
-#endif
+			if( output & LIS_PRINT_OUT && A->my_rank==0 ) lis_print_rhistory(iter,nrm2);
 		}
 
 		if( tol > nrm2 )
